@@ -443,6 +443,9 @@ class AlertElement(object):
     def accept(self):
         self._alert.accept()
 
+    def dismiss(self):
+        self._alert.dismiss()
+
     def fill_with(self, text):
         self._alert.send_keys(text)
 
